@@ -184,7 +184,7 @@ def merge_polygon(data,col):
     data1[col] = groupnames
     return data1
 
-def polyon_exterior(data):
+def polyon_exterior(data,minarea = 0):
     '''
     输入多边形GeoDataFrame数据，对多边形取外边界构成新多边形
     
@@ -192,6 +192,8 @@ def polyon_exterior(data):
     -------
     data : GeoDataFrame
         多边形数据
+    minarea : number
+        最小面积，小于这个面积的面全部剔除
         
     输出
     -------
@@ -204,9 +206,15 @@ def polyon_exterior(data):
         if type(p)==MultiPolygon:
             geometries = []
             for i in p:
-                geometries.append(Polygon(i.exterior))
+                poly = Polygon(i.exterior)
+                if minarea>0:
+                    if poly.area>minarea:
+                        geometries.append(poly)
+                else:
+                    geometries.append(poly)
             return MultiPolygon(geometries)
         if type(p)==Polygon:
             return Polygon(p.exterior)
     data1['geometry'] = data1['geometry'].apply(lambda r:polyexterior(r))
+    data1 = data1[-data1['geometry'].is_empty]
     return data1
